Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Camera ¶
type Camera struct {
DisplayName string `json:"displayName"`
TiltUp string `json:"tiltUp"`
TiltDown string `json:"tiltDown"`
PanLeft string `json:"panLeft"`
PanRight string `json:"panRight"`
PanTiltStop string `json:"panTiltStop"`
ZoomIn string `json:"zoomIn"`
ZoomOut string `json:"zoomOut"`
ZoomStop string `json:"zoomStop"`
Stream string `json:"stream"`
Presets []CameraPreset `json:"presets"`
}
type CameraPreset ¶
type ConfigService ¶
type ConfigService interface {
// RoomAndControlGroup returns the room and control group associated with a PC's hostname
RoomAndControlGroup(ctx context.Context, hostname string) (string, string, error)
// Cameras returns the camera configurations for the given room and control group
Cameras(ctx context.Context, room, controlGroup string) ([]Camera, error)
}
ConfigService talks the a datastore to get configuration information.
Click to show internal directories.
Click to hide internal directories.